@@ -50,6 +50,7 @@ import os
 import sys
 
 from mercurial.i18n import _
+from mercurial.pycompat import getattr, setattr
 from mercurial import (
     encoding,
     error,
@@ -61,25 +62,26 @@ from mercurial import (
 # extensions which SHIP WITH MERCURIAL. Non-mainline extensions should
 # be specifying the version(s) of Mercurial they are tested with, or
 # leave the attribute unspecified.
-testedwith = 'ships-with-hg-core'
+testedwith = b'ships-with-hg-core'
 
 configtable = {}
 configitem = registrar.configitem(configtable)
 
 # Encoding.encoding may be updated by --encoding option.
 # Use a lambda do delay the resolution.
-configitem('win32mbcs', 'encoding',
-    default=lambda: encoding.encoding,
+configitem(
+    b'win32mbcs', b'encoding', default=lambda: encoding.encoding,
 )
 
-_encoding = None                                # see extsetup
+_encoding = None  # see extsetup
+
 
 def decode(arg):
-    if isinstance(arg, str):
+    if isinstance(arg, bytes):
         uarg = arg.decode(_encoding)
         if arg == uarg.encode(_encoding):
             return uarg
-        raise UnicodeError("Not local encoding")
+        raise UnicodeError(b"Not local encoding")
     elif isinstance(arg, tuple):
         return tuple(map(decode, arg))
     elif isinstance(arg, list):
@@ -89,6 +91,7 @@ def decode(arg):
             arg[k] = decode(v)
     return arg
 
+
 def encode(arg):
     if isinstance(arg, pycompat.unicode):
         return arg.encode(_encoding)
@@ -101,13 +104,14 @@ def encode(arg):
             arg[k] = encode(v)
     return arg
 
+
 def appendsep(s):
     # ensure the path ends with os.sep, appending it if necessary.
     try:
         us = decode(s)
     except UnicodeError:
         us = s
-    if us and us[-1] not in ':/\\':
+    if us and us[-1] not in b':/\\':
         s += pycompat.ossep
     return s
 
@@ -123,8 +127,11 @@ def basewrapper(func, argtype, enc, dec, args, kwds):
         # return value.
         return enc(func(*dec(args), **dec(kwds)))
     except UnicodeError:
-        raise error.Abort(_("[win32mbcs] filename conversion failed with"
-                         " %s encoding\n") % (_encoding))
+        raise error.Abort(
+            _(b"[win32mbcs] filename conversion failed with %s encoding\n")
+            % _encoding
+        )
+
 
 def wrapper(func, args, kwds):
     return basewrapper(func, pycompat.unicode, encode, decode, args, kwds)
@@ -133,29 +140,34 @@ def wrapper(func, args, kwds):
 def reversewrapper(func, args, kwds):
     return basewrapper(func, str, decode, encode, args, kwds)
 
+
 def wrapperforlistdir(func, args, kwds):
     # Ensure 'path' argument ends with os.sep to avoids
     # misinterpreting last 0x5c of MBCS 2nd byte as path separator.
     if args:
         args = list(args)
         args[0] = appendsep(args[0])
-    if 'path' in kwds:
-        kwds['path'] = appendsep(kwds['path'])
+    if b'path' in kwds:
+        kwds[b'path'] = appendsep(kwds[b'path'])
     return func(*args, **kwds)
 
+
 def wrapname(name, wrapper):
-    module, name = name.rsplit('.', 1)
+    module, name = name.rsplit(b'.', 1)
     module = sys.modules[module]
     func = getattr(module, name)
+
     def f(*args, **kwds):
         return wrapper(func, args, kwds)
+
     f.__name__ = func.__name__
     setattr(module, name, f)
 
+
 # List of functions to be wrapped.
 # NOTE: os.path.dirname() and os.path.basename() are safe because
 #       they use result of os.path.split()
-funcs = '''os.path.join os.path.split os.path.splitext
+funcs = b'''os.path.join os.path.split os.path.splitext
  os.path.normpath os.makedirs mercurial.util.endswithsep
  mercurial.util.splitpath mercurial.util.fscasesensitive
  mercurial.util.fspath mercurial.util.pconvert mercurial.util.normpath
@@ -165,27 +177,29 @@ funcs = '''os.path.join os.path.split os.path.splitext
 # These functions are required to be called with local encoded string
 # because they expects argument is local encoded string and cause
 # problem with unicode string.
-rfuncs = '''mercurial.encoding.upper mercurial.encoding.lower
+rfuncs = b'''mercurial.encoding.upper mercurial.encoding.lower
  mercurial.util._filenamebytestr'''
 
 # List of Windows specific functions to be wrapped.
-winfuncs = '''os.path.splitunc'''
+winfuncs = b'''os.path.splitunc'''
 
 # codec and alias names of sjis and big5 to be faked.
-problematic_encodings = '''big5 big5-tw csbig5 big5hkscs big5-hkscs
+problematic_encodings = b'''big5 big5-tw csbig5 big5hkscs big5-hkscs
  hkscs cp932 932 ms932 mskanji ms-kanji shift_jis csshiftjis shiftjis
  sjis s_jis shift_jis_2004 shiftjis2004 sjis_2004 sjis2004
  shift_jisx0213 shiftjisx0213 sjisx0213 s_jisx0213 950 cp950 ms950 '''
 
+
 def extsetup(ui):
     # TODO: decide use of config section for this extension
-    if ((not os.path.supports_unicode_filenames) and
-        (pycompat.sysplatform != 'cygwin')):
-        ui.warn(_("[win32mbcs] cannot activate on this platform.\n"))
+    if (not os.path.supports_unicode_filenames) and (
+        pycompat.sysplatform != b'cygwin'
+    ):
+        ui.warn(_(b"[win32mbcs] cannot activate on this platform.\n"))
         return
     # determine encoding for filename
     global _encoding
-    _encoding = ui.config('win32mbcs', 'encoding')
+    _encoding = ui.config(b'win32mbcs', b'encoding')
     # fake is only for relevant environment.
     if _encoding.lower() in problematic_encodings.split():
         for f in funcs.split():
@@ -193,14 +207,15 @@ def extsetup(ui):
         if pycompat.iswindows:
             for f in winfuncs.split():
                 wrapname(f, wrapper)
-        wrapname("mercurial.util.listdir", wrapperforlistdir)
-        wrapname("mercurial.windows.listdir", wrapperforlistdir)
+        wrapname(b"mercurial.util.listdir", wrapperforlistdir)
+        wrapname(b"mercurial.windows.listdir", wrapperforlistdir)
         # wrap functions to be called with local byte string arguments
         for f in rfuncs.split():
             wrapname(f, reversewrapper)
         # Check sys.args manually instead of using ui.debug() because
         # command line options is not yet applied when
         # extensions.loadall() is called.
-        if '--debug' in sys.argv:
-            ui.write(("[win32mbcs] activated with encoding: %s\n")
-                     % _encoding)
+        if b'--debug' in sys.argv:
+            ui.writenoi18n(
+                b"[win32mbcs] activated with encoding: %s\n" % _encoding
+            )
